@@ -1,6 +1,8 @@
 #include <glibtop.h>
 #include <glibtop/fsusage.h>
 
+#include "glibtop_private.h"
+
 #include <glib.h>
 
 #include <mntent.h>
@@ -28,9 +30,7 @@ static void linux_2_6_0(glibtop *server, glibtop_fsusage *buf, const char *path)
 
   while((emnt = getmntent(mtab)) != NULL)
     {
-      if(strcmp(emnt->mnt_dir, path) != 0)
-	continue;
-      else
+      if(strcmp(emnt->mnt_dir, path) == 0)
       {
       char filename[64]; /* magic */
 
@@ -76,6 +76,10 @@ static void linux_2_6_0(glibtop *server, glibtop_fsusage *buf, const char *path)
       buf->read = strtoull(p, &p, 0);
       p = skip_token(p);
       buf->write = strtoull(p, &p, 0);
+
+      buf->flags |= (1 << GLIBTOP_FSUSAGE_READ) | (1 << GLIBTOP_FSUSAGE_WRITE);
+
+      break;
       }
     }
 
